import 'reflect-metadata'
import {Container} from "typedi"
import {PostService} from "../services/post-service"
import express from "express"
import {body} from "express-validator"
import * as Validator from "validator"
import {hasValidationErrors} from "../includes"

let postService = Container.get(PostService)

let postRouter = express.Router()
postRouter.post('/submit',
    body('content').notEmpty().withMessage('请输入内容')
        .escape(),
    body('image').isJSON().withMessage('图片必须为JSON格式').bail().custom((input, {req}) => {
        let arr: string[] = JSON.parse(input)
        if(!arr.length){
            throw new Error('图片数量至少为1')
        }
        for (let url of arr) {
            if (!Validator.default.isURL(url, {host_whitelist: [/.*\.360buyimg\.com/]})) {
                throw new Error('必须是360buyimg.com下的图片')
            }
        }
        req.body.imageArr = arr
        return true
    }),
    (req: express.Request, res: express.Response) => {
        if (hasValidationErrors(req, res)) return
        res.json(postService.submit(req.body.content, req.body.imageArr))
    }
)

export {postRouter}
